summaryrefslogtreecommitdiff
path: root/basctl
diff options
context:
space:
mode:
authorThomas Benisch <tbe@openoffice.org>2001-05-04 10:10:36 +0000
committerThomas Benisch <tbe@openoffice.org>2001-05-04 10:10:36 +0000
commit058b0ff211843ad4afa85a0e6c8f213aa5e3fafb (patch)
tree24cbc58d1a5795e968323291b958174ff02ada3d /basctl
parent24645d80f56c6549a5aaf0019a3882091ecfd3e6 (diff)
added FixedLine
Diffstat (limited to 'basctl')
-rw-r--r--basctl/source/dlged/dlgedfac.cxx15
-rw-r--r--basctl/source/dlged/dlgedobj.cxx14
-rw-r--r--basctl/source/dlged/dlgresid.src9
-rw-r--r--basctl/source/dlged/propbrw.cxx8
-rw-r--r--basctl/source/inc/dlgresid.hrc5
5 files changed, 35 insertions, 16 deletions
diff --git a/basctl/source/dlged/dlgedobj.cxx b/basctl/source/dlged/dlgedobj.cxx
index 8f1fca93ce88..ea77abbe6185 100644
--- a/basctl/source/dlged/dlgedobj.cxx
+++ b/basctl/source/dlged/dlgedobj.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: dlgedobj.cxx,v $
*
- * $Revision: 1.16 $
+ * $Revision: 1.17 $
*
- * last change: $Author: tbe $ $Date: 2001-05-02 12:37:48 $
+ * last change: $Author: tbe $ $Date: 2001-05-04 11:09:19 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -782,6 +782,10 @@ void SAL_CALL DlgEdObj::TabIndexChange( const ::com::sun::star::beans::Property
{
nResId = RID_STR_CLASS_SCROLLBAR;
}
+ else if (aServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.awt.UnoControlFixedLineModel") ))
+ {
+ nResId = RID_STR_CLASS_FIXEDLINE;
+ }
if (nResId)
{
@@ -888,7 +892,11 @@ sal_uInt16 DlgEdObj::GetObjIdentifier() const
}
else if (aServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.awt.UnoControlScrollBarModel") ))
{
- return OBJ_DLG_VSCROLLBAR; // ???change this??? OBJ_DLG_HSCROLLBAR
+ return OBJ_DLG_HSCROLLBAR; // ???change this??? OBJ_DLG_VSCROLLBAR
+ }
+ else if (aServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.awt.UnoControlFixedLineModel") ))
+ {
+ return OBJ_DLG_URLBUTTON; // ???change this!
}
else
{
diff --git a/basctl/source/dlged/dlgresid.src b/basctl/source/dlged/dlgresid.src
index 57dc3dccc9d1..9b3be8a29117 100644
--- a/basctl/source/dlged/dlgresid.src
+++ b/basctl/source/dlged/dlgresid.src
@@ -2,9 +2,9 @@
*
* $RCSfile: dlgresid.src,v $
*
- * $Revision: 1.7 $
+ * $Revision: 1.8 $
*
- * last change: $Author: tbe $ $Date: 2001-05-02 12:38:24 $
+ * last change: $Author: tbe $ $Date: 2001-05-04 11:09:32 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -111,6 +111,11 @@ String RID_STR_CLASS_SCROLLBAR
{
Text = "ScrollBar" ;
};
+String RID_STR_CLASS_FIXEDLINE
+{
+ Text = "FixedLine" ;
+};
+
// Property Browser Headline ----------------------------------------------------------------
diff --git a/basctl/source/dlged/propbrw.cxx b/basctl/source/dlged/propbrw.cxx
index 8e327d081aaf..8ad19cc375c0 100644
--- a/basctl/source/dlged/propbrw.cxx
+++ b/basctl/source/dlged/propbrw.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: propbrw.cxx,v $
*
- * $Revision: 1.5 $
+ * $Revision: 1.6 $
*
- * last change: $Author: tbe $ $Date: 2001-05-02 12:38:36 $
+ * last change: $Author: tbe $ $Date: 2001-05-04 11:09:44 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -481,6 +481,10 @@ void PropBrw::implSetNewObject(const Reference< XPropertySet >& _rxObject)
{
nResId = RID_STR_CLASS_SCROLLBAR;
}
+ else if (aServiceName.equalsAsciiL( RTL_CONSTASCII_STRINGPARAM("com.sun.star.awt.UnoControlFixedLineModel") ))
+ {
+ nResId = RID_STR_CLASS_FIXEDLINE;
+ }
if (nResId)
{
diff --git a/basctl/source/inc/dlgresid.hrc b/basctl/source/inc/dlgresid.hrc
index 3207936d46fb..d2e805daf0c1 100644
--- a/basctl/source/inc/dlgresid.hrc
+++ b/basctl/source/inc/dlgresid.hrc
@@ -2,9 +2,9 @@
*
* $RCSfile: dlgresid.hrc,v $
*
- * $Revision: 1.3 $
+ * $Revision: 1.4 $
*
- * last change: $Author: tbe $ $Date: 2001-05-02 12:39:47 $
+ * last change: $Author: tbe $ $Date: 2001-05-04 11:10:36 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -80,6 +80,7 @@
#define RID_STR_CLASS_IMAGECONTROL ( RID_DLG_START + 9 )
#define RID_STR_CLASS_PROGRESSBAR ( RID_DLG_START + 10 )
#define RID_STR_CLASS_SCROLLBAR ( RID_DLG_START + 11 )
+#define RID_STR_CLASS_FIXEDLINE ( RID_DLG_START + 12 )
// Property Browser Headline Id's -----------------------------------------------------------
diff --git a/basctl/source/dlged/dlgedfac.cxx b/basctl/source/dlged/dlgedfac.cxx
index 3db41c0e82f8..29fb87dc2775 100644
--- a/basctl/source/dlged/dlgedfac.cxx
+++ b/basctl/source/dlged/dlgedfac.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: dlgedfac.cxx,v $
*
- * $Revision: 1.6 $
+ * $Revision: 1.7 $
*
- * last change: $Author: tbe $ $Date: 2001-05-02 12:37:36 $
+ * last change: $Author: tbe $ $Date: 2001-05-04 11:09:09 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -180,17 +180,20 @@ IMPL_LINK( DlgEdFactory, MakeObject, SdrObjFactory *, pObjFactory )
pObjFactory->pNewObj = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlProgressBarModel"), xDialogSFact);
break;
case OBJ_DLG_HSCROLLBAR:
+ pObjFactory->pNewObj = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlScrollBarModel"), xDialogSFact);
+ break;
+ case OBJ_DLG_VSCROLLBAR:
{
DlgEdObj* pNew = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlScrollBarModel"), xDialogSFact);
pObjFactory->pNewObj = pNew;
// set horizontal orientation
try
{
uno::Reference< beans::XPropertySet > xPSet(pNew->GetUnoControlModel(), uno::UNO_QUERY);
if (xPSet.is())
{
uno::Any aValue;
- aValue <<= (sal_Int32) ::com::sun::star::awt::ScrollBarOrientation::HORIZONTAL;
+ aValue <<= (sal_Int32) ::com::sun::star::awt::ScrollBarOrientation::VERTICAL;
xPSet->setPropertyValue( ::rtl::OUString(RTL_CONSTASCII_USTRINGPARAM( "Orientation" ) ), aValue );
}
}
@@ -198,10 +201,8 @@ IMPL_LINK( DlgEdFactory, MakeObject, SdrObjFactory *, pObjFactory )
{
}
} break;
- case OBJ_DLG_VSCROLLBAR:
- pObjFactory->pNewObj = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlScrollBarModel"), xDialogSFact);
- break;
case OBJ_DLG_URLBUTTON:
+ pObjFactory->pNewObj = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlFixedLineModel"), xDialogSFact);
break;
}
@@ -180,17 +180,20 @@ IMPL_LINK( DlgEdFactory, MakeObject, SdrObjFactory *, pObjFactory )
DlgEdObj* pNew = new DlgEdObj(rtl::OUString::createFromAscii("com.sun.star.awt.UnoControlScrollBarModel"), xDialogSFact);
pObjFactory->pNewObj = pNew;
- // set horizontal orientation
+ // set vertical orientation
try
{